;************************************************************************
Pro model_reader,file_name,coeffs,latmin, $
   phi_tot=phi_tot,chi_sqr=chi_sqr,rms_err=rms_err,order=order
;
;    This procedure reads in the coeffients of the spherical harmonic
;    expansion describing the statistical convection pattern
;
;  INPUT:
;    file_name: name of file containing coefficients
;
;    NOTE: the naming convention of the file names is as follows: 
;    - the 'omni' prefix indcates we used solar wind data from OMNI
;    - then 'north' or 'south' indicates the hemisphere
;    - the numbers 0.00t1.20, 1.20t1.70, etc. indicate the Esw magnitude bin in mV/m
;    - the string Bz+_By+ etc. indicates the IMF clock angle bin
;    - the string DP-,DP0,DP+ indicates negative neutral, or positive
;      tilt (for either hemispere, positive tilt is summer-like conditions)
;
;  RETURN VALUE:
;    coeffs:  This argument is an array defining the coefficients of
;             the expansion.  It is an array (4, kmax) where kmax is
;             the number of coefficients.  The structure is:
;        
;       index:  0           1            2            3
;              ----------------------------------------------
;              L-index    M-index      value        sigma
;
;       where the L-index gives the L value from 0 to Lmax 
;                 M-index gives the M value from -L to +L, with
;                 the negative values indicating the sin(M*phi)
;                 terms.
;                 Value is the estimator for the coefficient's value
;                 and sigma is the estimator for the 1-sigma error
;                 bars on the value.
;
;       NOTE that the organization is as follows:
;                0           0          A(0,0)     sigma(0,0)
;                1           0          A(1,0)     sigma(1,0)
;                1           1          A(1,1)     sigma(1,1)
;                1          -1          B(1,1)     sigma(1,-1)
;                2           0          A(2,0)     sigma(2,0)
;                2           1          A(2,1)     sigma(2,1)
;                2          -1          B(2,1)     sigma(2,-1)
;                2           2          A(2,2)     sigma(2,2)
;                              ETC.
;
;           The translation from index L,M to index k is given by the
;           function legendre_index and its inverse k_to_lm_index.
;
;    latmin:   Low-latitude zero-potential boundary of expansion
;
;  OPTIONAL RETURNED VALUES:
;    chi_sqr:  This returns the chi_square value of the fit.
; 
;    phi_tot:  This returns the total potential drop across the polar
;              cap in Volts.
;
;    rms_err:  This returns the rms error value of the fit (in m/s)
;
;    order:    This returns the order of the fit
;
;  AUTHOR: Ellen Pettigrew Cousins, Dartmouth College
;          Dec, 2010
;
;  EXAMPLE CALLING SEQUENCE:
;  model_reader,'omni.north_2.20t2.90_By-_DP-.bsph',coeffs,latmin,phi_tot=phi_tot
;*************************************************************************
;

openr,sph_unit,file_name,/get_lun

annot_str  =  ' '
readf,sph_unit,annot_str
readf,sph_unit,n_bin,calc_var_flag
readf,sph_unit,n_cen,xlat_cen,xlon_cen,xrho_cen
readf,sph_unit,order,dim_1,dim_2,latmin,phi_tot
readf,sph_unit,latzer,chi_sqr,degfree,rms_err,phi_tot, $
               chi_sqr_dat,degfree_dat,vmag_max,verr_min, $
               error_wt_flag,model_wt_flag
coeffs  =  fltarr(dim_1,dim_2)
readf,sph_unit,coeffs

close,sph_unit
free_lun,sph_unit

end
